@@ -29,23 +29,33 @@ cons4Stab <- function(consMatrix, numVar, longitudinal) {
 
   if (longitudinal) {
 
-    #swap column, for intra, and add with NumVar to get correct indices
-    #in longitudinal model
-    cons_intra <- consMatrix[, c(2, 1)] + numVar
-
-    # constraint for inter
+    #create constraint for inter
     cons_inter <- NULL
     for (i in 1:numVar) {
       cons_inter <- rbind(cons_inter,
                           matrix(c(c(1:numVar), rep(numVar + i, numVar)),
                                  numVar, 2))
     }
-    return(rbind(cons_intra, cons_inter))
+
+    #swap column, for intra, and add with NumVar to get correct indices
+    #in longitudinal model
+    #in case no constraint
+    if (nrow(consMatrix) == 1 & all(consMatrix == 0)) {
+      return(cons_inter)
+    } else {
+      cons_intra <- consMatrix[, c(2, 1)] + numVar
+      return(rbind(cons_intra, cons_inter))
+    }
 
   } else { #if cross-sectional
 
     #swap the column, e.g., 1 becomes 2 and vice versa
-    return(consMatrix[, c(2, 1)])
+    #in case no constraint
+    if (nrow(consMatrix) == 1 & all(consMatrix == 0)) {
+      return(matrix(0, 1, 2, byrow = TRUE))
 
+    } else {
+      return(consMatrix[, c(2, 1)])
     }
+  }
 }
